@@ -20,7 +20,7 @@
 #define _mxMailApp_h
 #ifdef __cplusplus
 
-#include <std/string.h>
+#include <string>
 #include "akApp.h"
 #include "akSound.h"
 
