@@ -16,7 +16,7 @@
 #define _mxMailAttachmentSpecify_h
 #ifdef __cplusplus
 
-#include <std/string.h>
+#include <string>
 #include "akDialog.h"
 #include "akPromptFile.h"
 #include "akOptionMenu.h"
