@@ -17,8 +17,7 @@
 #define mxQuotedPrintableString_h
 #ifdef __cplusplus
 
-#include <std/string.h>
-#include <bool.h>
+#include <string>
 
 class mxQuotedPrintableString
 {
@@ -30,7 +29,7 @@ class mxQuotedPrintableString
 
 		// Methods
 
-		string		decode(string,bool text_mode=TRUE);
+		string		decode(string,bool text_mode=true);
 
 	private:
 
